@@ -135,9 +135,10 @@ def plot_timeseries(
         au.stack_plot(plot_df, stacked_techs, colormap=colormap,
                       alpha=0.9, ticks=ticks, legend=None, names=names,
                       ax=ax)
-    ax.plot(plot_df[demand].index,
-            plot_df[demand] * -1,
-            color='red', lw=1.5, ls='--', label=df.at[demand, 'name'])
+    if demand in plot_df.columns:
+        ax.plot(plot_df[demand].index,
+                plot_df[demand] * -1,
+                color='red', lw=1.5, ls='--', label=df.at[demand, 'name'])
     # Add legend here rather than in stack_plot so we get demand too
     if add_legend:
         au.legend_outside_ax(ax, where='right')
@@ -176,7 +177,7 @@ def plot_installed_capacities(
     md = solution.metadata.to_pandas()
     supply_cap = md.query(query_string).index.tolist()
 
-    df = solution['e_cap'].loc[dict(y=supply_cap)].to_pandas()
+    df = solution['e_cap'].loc[dict(y=supply_cap)].to_pandas().T
 
     weighted = md.stack_weight.sort_values(ascending=False).index.tolist()
     stacked_techs = [y for y in weighted if y in df.columns]
