@@ -16,7 +16,7 @@ from . import core
 
 PATHS = {
     'NationalScale': os.path.join(os.path.dirname(__file__), 'example_models', 'national_scale'),
-    'UrbanScale': os.path.join(os.path.dirname(__file__), 'example_models', 'urban_scale'),
+    'UrbanScale': os.path.join(os.path.dirname(__file__), 'example_models', 'urban_scale')
 }
 
 
@@ -40,3 +40,13 @@ class UrbanScale(core.Model):
     def __init__(self, override=None):
         config_run = os.path.join(PATHS['UrbanScale'], 'run.yaml')
         super().__init__(config_run=config_run, override=override)
+
+class MILP(core.Model):
+    """
+    Mixed Integer Linear Programming (MILP) functionality example model.
+
+    """
+
+    def __init__(self, override=None):
+        config_run = os.path.join(PATHS['UrbanScale'], 'run_milp.yaml')
+        super().__init__(config_run=config_run, override=override)
